# -*- coding: utf-8 -*-
'''
Created on Fri Jan 10 14:00:59 2025

@author: mstep
'''

'''The custom SettingsDialog class.'''
import tkinter as tk
from tkinter import messagebox

class SettingsDialog(tk.Toplevel):
    def __init__(self, master, num_rows=5, num_columns=5):
        super().__init__(master)
        self.transient(master)  # Keep dialog above master.
        self.minsize(300, 200)
        self.title('Settings')
        self.num_rows = None
        self.num_cols = None

        # Make a frame to hold the dialog's main body.
        main_frame = tk.Frame(self)
        main_frame.pack(side=tk.TOP, fill=tk.BOTH, expand=True, padx=10, pady=10)

        # Build the dialog's widgets.
        num_rows_label = tk.Label(main_frame, text='# Rows:')
        num_rows_label.grid(row=0, column=0, sticky=tk.W, padx=5, pady=5)
        self.num_rows_entry = tk.Entry(main_frame)
        self.num_rows_entry.insert(0, f'{num_rows}')
        self.num_rows_entry.selection_range(0, tk.END)
        self.num_rows_entry.grid(row=0, column=1, sticky=tk.W, padx=5, pady=5)

        num_cols_label = tk.Label(main_frame, text='# Columns:')
        num_cols_label.grid(row=1, column=0, sticky=tk.W, padx=5, pady=5)
        self.num_cols_entry = tk.Entry(main_frame)
        self.num_cols_entry.insert(0, f'{num_columns}')
        self.num_cols_entry.selection_range(0, tk.END)
        self.num_cols_entry.grid(row=1, column=1, sticky=tk.W, padx=5, pady=5)

        # Make OK and Cancel buttons.
        button_frame = tk.Frame(self, height=5)
        button_frame.pack(side=tk.RIGHT, fill=tk.X, expand=False, padx=10, pady=10)

        ok_button = tk.Button(button_frame, text='OK', width=7,
            command=self.ok_click)
        ok_button.pack(side=tk.LEFT, padx=10, pady=10)
        self.bind('<Return>', lambda event: self.ok_click())

        cancel_button = tk.Button(button_frame, text='Cancel', width=7,
            command=self.cancel_click)
        cancel_button.pack(side=tk.LEFT, padx=10, pady=10)
        self.bind('<Escape>', lambda event: self.cancel_click())

        self.num_rows_entry.focus_set()

        # Grab events for this dialog.
        self.grab_set()

    def cancel_click(self):
        '''Close the dialog.'''
        self.destroy()

    def ok_click(self):
        '''Validate the user's entries and close the dialog.'''
        if not self.validate(): return

        # Close the dialog.
        self.withdraw()
        self.update_idletasks()
        self.cancel_click()

    def validate(self):
        '''
        Validate the user's entries.
        Display an error message if appropriate.
        Return True if the entries are valid, False otherwise.
        '''
        try:
            num_rows = int(self.num_rows_entry.get())
        except:
            num_rows = 0
        if num_rows <= 0:
            messagebox.showerror('Error',
                'The number of rows should be a positive integer.')
            self.num_rows_entry.focus_set()
            return False

        try:
            num_cols = int(self.num_cols_entry.get())
        except:
            num_cols = 0
        if num_cols <= 0:
            messagebox.showerror('Error',
                'The number of columns should be a positive integer.')
            self.num_cols_entry.focus_set()
            return False

        # Save the validated values.
        self.num_rows = num_rows
        self.num_cols = num_cols
        return True

    def show(self):
        '''Display the dialog, wait for it to end, and return its results.'''
        self.wait_window()
        return self.num_rows, self.num_cols

#%%

import tkinter as tk
from PIL import ImageTk

class CustomDialogApp:
    def __init__(self):
        self.window = tk.Tk()

        self.window.title('custom_dialog')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry('300x300')

        # Build the menu.
        self.build_menus()

        # Build other stuff...
        label = tk.Label(self.window, text='First Name:')
        label.grid(row=0, column=0, padx=5, pady=(5,0))
        first_name_entry = tk.Entry(self.window)
        first_name_entry.grid(row=0, column=1, padx=5, pady=(5,0))
        first_name_entry.focus_force()

        label = tk.Label(self.window, text='Last Name:')
        label.grid(row=1, column=0, padx=5, pady=(5,0))
        last_name_entry = tk.Entry(self.window)
        last_name_entry.grid(row=1, column=1, padx=5, pady=(5,0))

        # Display the window.
        self.window.mainloop()

    def build_menus(self):
        '''Build the menu bar.'''
        menu_bar = tk.Menu(self.window)
        self.window.config(menu=menu_bar)
        self.build_file_menu(menu_bar)
        self.build_config_menu(menu_bar)

    def build_file_menu(self, menu_bar):
        '''Build the File menu.'''
        file_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='File', menu=file_menu)

        # Exit
        self.exit_photo_image = ImageTk.PhotoImage(file='exit.png')
        file_menu.add_command(label='Exit', compound='left',
            command=self.mnu_exit, image=self.exit_photo_image)

    def build_config_menu(self, menu_bar):
        '''Build the Configuration menu.'''
        config_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='Configuration', menu=config_menu)

        # Settings
        self.settings_image = ImageTk.PhotoImage(file='settings.png')
        config_menu.add_command(label='Settings...', compound='left',
            command=self.mnu_settings, image=self.settings_image)

    def mnu_exit(self):
        self.kill_callback()

    def kill_callback(self):
        # Destroy the tkinter window.
        self.window.destroy()

    def mnu_settings(self):
        '''Display the SettingsDialog and show the returned results.'''
        print(SettingsDialog(self.window, 5, 8).show())

# In[19]:
CustomDialogApp()
print('Done')
